# BitSightAPI

This is a Python wrapper for the BitSight API. It provides a method to test the connection to the API (using the Requests module) and a method to query the API.

Currently the wrapper only supports GET requests, but updates will be made to support others, as well as implement query parameters and particular endpoints.

_Disclaimer: I'm not an employee or affiliate of BitSight. I created this Python module as an enthusiastic user who needed to satisfy a particular use-case and, as such, you should not consider this software to be a professional product. Neither I nor BitSight accept any liability or responsibility for any problems that occur as a result of using this software._
